#[repr(u8)]pub enum NoPrgm {
NO_PRGM_OFF = 0,
NO_PRGM_ON = 1,
}Variants
NO_PRGM_OFF = 0
Programability of registers controlled only by the Miscellaneous Control Register’s access mode bit.
NO_PRGM_ON = 1
Overides Miscellaneous Control Register access mode and prevents TRNG register programming.
Implementations