#[repr(u8)]pub enum SampMode {
SAMP_MODE_VON_BOTH = 0,
SAMP_MODE_RAW_BOTH = 1,
SAMP_MODE_VON_ENT = 2,
SAMP_MODE_UNDEF = 3,
}Variants
SAMP_MODE_VON_BOTH = 0
use Von Neumann data into both Entropy shifter and Statistical Checker.
SAMP_MODE_RAW_BOTH = 1
use raw data into both Entropy shifter and Statistical Checker.
SAMP_MODE_VON_ENT = 2
use Von Neumann data into Entropy shifter. Use raw data into Statistical Checker.
SAMP_MODE_UNDEF = 3
undefined/reserved.
Implementations